@@ -463,3 +463,40 @@ test_that("Batch single-crit internal tuning works", {
   expect_equal(instance$result_learner_param_vals$iter, 99)
 })
 
+test_that("required parameter can be tuned internally without having a value set", {
+  learner = lrn("classif.debug")
+  tags = learner$param_set$tags
+  tags$iter = union(tags$iter, "required")
+  learner$param_set$tags = tags
+
+  learner$param_set$set_values(
+    early_stopping = TRUE,
+    iter = NULL
+  )
+  learner$validate = "test"
+
+  internal_search_space = ps(
+    iter = p_int(upper = 1000, aggr = function(x) as.integer(mean(unlist(x))))
+  )
+
+
+  expect_error(tune(
+    task = tsk("iris"),
+    tuner = tnr("internal"),
+    learner = learner,
+    internal_search_space = internal_search_space,
+    resampling = rsmp("holdout"),
+    store_benchmark_result = TRUE
+  ), regexp = NA)
+
+  learner$param_set$set_values(
+    iter = to_tune(upper = 1000, internal = TRUE)
+  )
+  expect_error(tune(
+    task = tsk("iris"),
+    tuner = tnr("internal"),
+    learner = learner,
+    resampling = rsmp("holdout"),
+    store_benchmark_result = TRUE
+  ), regexp = NA)
+})
